==> camel-k-model-v1-6.0.0-sources.jar: io/fabric8/camelk/v1/CamelLoaderBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CamelLoaderBuilder extends CamelLoaderFluentImpl<CamelLoaderBuilder> implements VisitableBuilder<CamelLoader,CamelLoaderBuilder>{
  public CamelLoaderBuilder() {
    this(false);
  }
  public CamelLoaderBuilder(Boolean validationEnabled) {
    this(new CamelLoader(), validationEnabled);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent) {
    this(fluent, false);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CamelLoader(), validationEnabled);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,CamelLoader instance) {
    this(fluent, instance, false);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,CamelLoader instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withArtifactId(instance.getArtifactId()); 
    fluent.withDependencies(instance.getDependencies()); 
    fluent.withGroupId(instance.getGroupId()); 
    fluent.withLanguages(instance.getLanguages()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public CamelLoaderBuilder(CamelLoader instance) {
    this(instance,false);
  }
  public CamelLoaderBuilder(CamelLoader instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withArtifactId(instance.getArtifactId()); 
    this.withDependencies(instance.getDependencies()); 
    this.withGroupId(instance.getGroupId()); 
    this.withLanguages(instance.getLanguages()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  CamelLoaderFluent<?> fluent;
  Boolean validationEnabled;
  public CamelLoader build() {
    CamelLoader buildable = new CamelLoader(fluent.getArtifactId(),fluent.getDependencies(),fluent.getGroupId(),fluent.getLanguages(),fluent.getVersion());
    return buildable;
  }
  
}

==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/CamelLoaderBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CamelLoaderBuilder extends CamelLoaderFluentImpl<CamelLoaderBuilder> implements VisitableBuilder<CamelLoader,CamelLoaderBuilder>{
  public CamelLoaderBuilder() {
    this(false);
  }
  public CamelLoaderBuilder(Boolean validationEnabled) {
    this(new CamelLoader(), validationEnabled);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent) {
    this(fluent, false);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CamelLoader(), validationEnabled);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,CamelLoader instance) {
    this(fluent, instance, false);
  }
  public CamelLoaderBuilder(CamelLoaderFluent<?> fluent,CamelLoader instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withArtifactId(instance.getArtifactId()); 
    fluent.withDependencies(instance.getDependencies()); 
    fluent.withGroupId(instance.getGroupId()); 
    fluent.withLanguages(instance.getLanguages()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public CamelLoaderBuilder(CamelLoader instance) {
    this(instance,false);
  }
  public CamelLoaderBuilder(CamelLoader instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withArtifactId(instance.getArtifactId()); 
    this.withDependencies(instance.getDependencies()); 
    this.withGroupId(instance.getGroupId()); 
    this.withLanguages(instance.getLanguages()); 
    this.withMetadata(instance.getMetadata()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  CamelLoaderFluent<?> fluent;
  Boolean validationEnabled;
  public CamelLoader build() {
    CamelLoader buildable = new CamelLoader(fluent.getArtifactId(),fluent.getDependencies(),fluent.getGroupId(),fluent.getLanguages(),fluent.getMetadata(),fluent.getVersion());
    return buildable;
  }
  
}
